# Table of Contents

- [fact-sheets](<./fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheets](<./Fact-Sheets.md>)
  - [Introduction](<./Fact-Sheets/Introduction.md>)
  - [Fact Sheet Layout](<./Fact-Sheets/Fact-Sheet-Layout.md>)
  - [Fact Sheet Types](<./Fact-Sheets/Fact-Sheet-Types.md>)
  - [Fact Sheet Subtypes](<./Fact-Sheets/Fact-Sheet-Subtypes.md>)
